BundleWrap is a decentralized configuration management system that is designed to be powerful, easy to extend and extremely versatile.

For more information, have a look at [bundlewrap.org](http://bundlewrap.org) and [docs.bundlewrap.org](http://docs.bundlewrap.org).

------------------------------------------------------------------------

<a href="https://pypi.python.org/pypi/bundlewrap/">
    <img src="http://img.shields.io/pypi/v/bundlewrap.svg" alt="Latest Version">
</a>
&nbsp;
<a href="https://travis-ci.org/bundlewrap/bundlewrap">
    <img src="http://img.shields.io/travis/bundlewrap/bundlewrap/master.svg" alt="Build status">
</a>
&nbsp;
<a href="https://pypi.python.org/pypi/bundlewrap/">
    <img src="http://img.shields.io/pypi/pyversions/bundlewrap.svg" alt="Python compatibility">
</a>

------------------------------------------------------------------------

Donations appreciated:

Bitcoin `13AJYksqncZromPF8HvDUXsmHChAm3Y7W7`

Ethereum `0x5Eb3037e197d3C0d2E014bcfC2e027EB0AD42812`

------------------------------------------------------------------------

BundleWrap is © 2013 - 2020 [Torsten Rehn](mailto:torsten@rehn.email)
